@@ -13,17 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import collections
+from importlib import resources
 import logging
 import os
 
-try:
-    from importlib import resources
-
-    if not hasattr(resources, "files"):
-        import importlib_resources as resources
-except ImportError:
-    import importlib_resources as resources
-
 import requests
 
 from sushy import auth as sushy_auth
@@ -205,7 +198,7 @@ class Sushy(base.ResourceBase):
                                                  password=password)
         self._auth = auth
 
-        super(Sushy, self).__init__(
+        super().__init__(
             connector or sushy_connector.Connector(
                 base_url, verify=verify,
                 server_side_retries=server_side_retries,
@@ -234,7 +227,7 @@ class Sushy(base.ResourceBase):
 
         :param json_doc: parsed JSON document in form of Python types
         """
-        super(Sushy, self)._parse_attributes(json_doc)
+        super()._parse_attributes(json_doc)
         self.redfish_version = json_doc.get('RedfishVersion')
 
     def get_system_collection(self):
