@@ -137,37 +137,8 @@ class VirtualMedia(base.ResourceBase):
 
         Try to determine if it happened due to missing Credentials
         """
-
-        # Accept broader variants seen on NVIDIA DGX where "code" may be absent
-        try:
-            body = error.response.json()
-        except Exception:
-            body = {}
-
-        # Structured path: @Message.ExtendedInfo entries
-        ext = (body.get('error', {}) or {}).get('@Message.ExtendedInfo',
-                                                []) or []
-        for m in ext:
-            mid = (m.get('MessageId') or '')
-            msg = (m.get('Message') or '')
-            if mid.endswith('ActionParameterMissing') and (
-                'UserName' in msg or 'Password' in msg):
-                return True
-
-        # Legacy/structured: error.code + message mentions UserName/Password
-        err_obj = (body.get('error') or {})
-        code = (err_obj.get('code') or '')
-        msg = (err_obj.get('message') or '')
-        if code.endswith('GeneralError') and (
-            'UserName' in msg or 'Password' in msg
-                or 'parameter missing' in msg):
-            return True
-
-        # Text fallback: common strings observed in the field
-        raw_msg = ((body.get('error') or {}).get('message') or '') + ' ' + (
-            error.detail or '')
-        if ('requires the parameter UserName' in raw_msg
-                or 'requires the parameter Password' in raw_msg):
+        if (error.code.endswith('GeneralError')
+                and 'UserName' in error.detail):
             return True
         return False
 
@@ -226,29 +197,38 @@ class VirtualMedia(base.ResourceBase):
                 payload['Inserted'] = False
             if not write_protected:
                 payload['WriteProtected'] = False
-            # NOTE(janders) attempting to detect whether attachment failure is
-            # due to absence of TransferProtocolType param and if so adding it
-            try:
-                self._conn.post(target_uri, data=payload)
-            except exceptions.HTTPError as error:
-                if self.is_transfer_protocol_required(error):
-                    if payload['Image'].startswith('https://'):
-                        payload['TransferProtocolType'] = "HTTPS"
-                    elif payload['Image'].startswith('http://'):
-                        payload['TransferProtocolType'] = "HTTP"
+            # Called a Max of 4 times, 1 plain + 1 for each of the 3 errors
+            for _ in range(4):
+                try:
+                    self._conn.post(target_uri, data=payload)
+                    break
+                except exceptions.HTTPError as error:
+                    # NOTE(janders) attempting to detect whether attachment
+                    # failure is due to absence of TransferProtocolType param
+                    # and if so adding it
+                    if payload.get('TransferProtocolType') is None and \
+                            self.is_transfer_protocol_required(error):
+                        if payload['Image'].startswith('https://'):
+                            payload['TransferProtocolType'] = "HTTPS"
+                        elif payload['Image'].startswith('http://'):
+                            payload['TransferProtocolType'] = "HTTP"
+                        continue
 
                     # NOTE (iurygregory) we try to handle the case where a
                     # a TransferMethod is also required in the payload.
-                    try:
-                        self._conn.post(target_uri, data=payload)
-                    except exceptions.HTTPError as error2:
-                        if self.is_transfer_method_required(error2):
-                            payload['TransferMethod'] = "Stream"
-                            self._conn.post(target_uri, data=payload)
-                        else:
-                            raise
+                    if payload.get('TransferMethod') != "Stream" and \
+                            self.is_transfer_method_required(error):
+                        payload['TransferMethod'] = "Stream"
+                        continue
 
-                else:
+                    # NOTE (derekh) we try to handle the case where
+                    # credentials are required in the payload.
+                    # Seen on nvidia dgx (Bug 2071945)
+                    if payload.get('UserName') is None and \
+                            self.is_credentials_required(error):
+                        payload['UserName'] = "none"
+                        payload['Password'] = "none"  # noqa:S105
+                        continue
                     raise
         self.invalidate()
 
