@@ -21,7 +21,7 @@ import logging
 from sushy import exceptions
 from sushy.resources import base
 from sushy.resources import common
-from sushy.resources.system import mappings as sys_maps
+from sushy.resources.system import constants as sys_cons
 from sushy import utils
 
 # Representation of Summary of Processor information
@@ -59,16 +59,15 @@ class Processor(base.ResourceBase):
     socket = base.Field('Socket')
     """The socket or location of the processor"""
 
-    processor_type = base.MappedField(
-        'ProcessorType', sys_maps.PROCESSOR_TYPE_VALUE_MAP)
+    processor_type = base.MappedField('ProcessorType', sys_cons.ProcessorType)
     """The type of processor"""
 
-    processor_architecture = base.MappedField(
-        'ProcessorArchitecture', sys_maps.PROCESSOR_ARCH_VALUE_MAP)
+    processor_architecture = base.MappedField('ProcessorArchitecture',
+                                              sys_cons.ProcessorArchitecture)
     """The architecture of the processor"""
 
-    instruction_set = base.MappedField(
-        'InstructionSet', sys_maps.PROCESSOR_INSTRUCTIONSET_VALUE_MAP)
+    instruction_set = base.MappedField('InstructionSet',
+                                       sys_cons.InstructionSet)
     """The instruction set of the processor"""
 
     manufacturer = base.Field('Manufacturer')
@@ -93,7 +92,7 @@ class Processor(base.ResourceBase):
     """The total number of execution threads supported by this processor"""
 
     def __init__(self, connector, identity, redfish_version=None,
-                 registries=None):
+                 registries=None, root=None):
         """A class representing a Processor
 
         :param connector: A Connector instance
@@ -102,25 +101,27 @@ class Processor(base.ResourceBase):
             the object according to schema of the given version.
         :param registries: Dict of Redfish Message Registry objects to be
             used in any resource that needs registries to parse messages
+        :param root: Sushy root object. Empty for Sushy root itself.
         """
-        super(Processor, self).__init__(
-            connector, identity, redfish_version, registries)
+        super().__init__(
+            connector, identity, redfish_version=redfish_version,
+            registries=registries, root=root)
 
-    def _get_processor_collection_path(self):
-        """Helper function to find the ProcessorCollection path"""
-        pro_col = self.json.get('ProcessorCollection')
-        if not pro_col:
+    def _get_subprocessor_collection_path(self):
+        """Helper function to find the SubProcessors path"""
+        subproc_col = self.json.get('SubProcessors')
+        if not subproc_col:
             raise exceptions.MissingAttributeError(
-                attribute='ProcessorCollection', resource=self._path)
-        return pro_col.get('@odata.id')
+                attribute='SubProcessors', resource=self._path)
+        return subproc_col.get('@odata.id')
 
     @property
     @utils.cache_it
     def sub_processors(self):
         """A reference to the collection of Sub-Processors"""
         return ProcessorCollection(
-            self.conn, self._get_processor_collection_path,
-            redfish_version=self.redfish_version)
+            self._conn, self._get_subprocessor_collection_path(),
+            redfish_version=self.redfish_version, root=self.root)
 
 
 class ProcessorCollection(base.ResourceCollectionBase):
@@ -156,7 +157,8 @@ class ProcessorCollection(base.ResourceCollectionBase):
 
         return ProcessorSummary(count=count, architecture=architecture)
 
-    def __init__(self, connector, path, redfish_version=None, registries=None):
+    def __init__(self, connector, path, redfish_version=None, registries=None,
+                 root=None):
         """A class representing a ProcessorCollection
 
         :param connector: A Connector instance
@@ -165,6 +167,9 @@ class ProcessorCollection(base.ResourceCollectionBase):
             the object according to schema of the given version.
         :param registries: Dict of Redfish Message Registry objects to be
             used in any resource that needs registries to parse messages
+        :param root: Sushy root object. Empty for Sushy root itself.
         """
-        super(ProcessorCollection, self).__init__(
-            connector, path, redfish_version, registries)
+        super().__init__(
+            connector, path, redfish_version=redfish_version,
+            registries=registries,
+            root=root)
