@@ -26,7 +26,7 @@ from sushy.tests.unit import base
 class ProcessorTestCase(base.TestCase):
 
     def setUp(self):
-        super(ProcessorTestCase, self).setUp()
+        super().setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/processor.json') as f:
             self.json_doc = json.load(f)
@@ -43,13 +43,12 @@ class ProcessorTestCase(base.TestCase):
         self.assertEqual('CPU1', self.sys_processor.identity)
         self.assertEqual('CPU 1', self.sys_processor.socket)
         self.assertEqual(
-            sushy.PROCESSOR_TYPE_CPU,
+            sushy.ProcessorType.CPU,
             self.sys_processor.processor_type)
-        self.assertEqual(sushy.PROCESSOR_ARCH_x86,
+        self.assertEqual(sushy.ProcessorArchitecture.X86,
                          self.sys_processor.processor_architecture)
-        self.assertEqual(
-            sushy.PROCESSOR_INSTRUCTIONSET_x86_64,
-            self.sys_processor.instruction_set)
+        self.assertEqual(sushy.InstructionSet.X86_64,
+                         self.sys_processor.instruction_set)
         self.assertEqual('Intel(R) Corporation',
                          self.sys_processor.manufacturer)
         self.assertEqual('Multi-Core Intel(R) Xeon(R) processor 7xxx Series',
@@ -71,10 +70,10 @@ class ProcessorTestCase(base.TestCase):
         self.assertEqual(3700, self.sys_processor.max_speed_mhz)
         self.assertEqual(8, self.sys_processor.total_cores)
         self.assertEqual(16, self.sys_processor.total_threads)
-        self.assertEqual(res_cons.STATE_ENABLED,
+        self.assertEqual(res_cons.State.ENABLED,
                          self.sys_processor.status.state)
-        self.assertEqual(res_cons.HEALTH_OK, self.sys_processor.status.health)
-        self.assertEqual(res_cons.HEALTH_OK,
+        self.assertEqual(res_cons.Health.OK, self.sys_processor.status.health)
+        self.assertEqual(res_cons.Health.OK,
                          self.sys_processor.status.health_rollup)
 
     def test_sub_processors(self):
@@ -103,7 +102,7 @@ class ProcessorTestCase(base.TestCase):
 class ProcessorCollectionTestCase(base.TestCase):
 
     def setUp(self):
-        super(ProcessorCollectionTestCase, self).setUp()
+        super().setUp()
         self.conn = mock.Mock()
         with open('sushy/tests/unit/json_samples/'
                   'processor_collection.json') as f:
@@ -130,7 +129,8 @@ class ProcessorCollectionTestCase(base.TestCase):
         mock_processor.assert_called_once_with(
             self.sys_processor_col._conn,
             '/redfish/v1/Systems/437XR1138R2/Processors/CPU1',
-            self.sys_processor_col.redfish_version, None)
+            redfish_version=self.sys_processor_col.redfish_version,
+            registries=None, root=self.sys_processor_col.root)
 
     @mock.patch.object(processor, 'Processor', autospec=True)
     def test_get_members(self, mock_processor):
@@ -138,10 +138,12 @@ class ProcessorCollectionTestCase(base.TestCase):
         calls = [
             mock.call(self.sys_processor_col._conn,
                       '/redfish/v1/Systems/437XR1138R2/Processors/CPU1',
-                      self.sys_processor_col.redfish_version, None),
+                      redfish_version=self.sys_processor_col.redfish_version,
+                      registries=None, root=self.sys_processor_col.root),
             mock.call(self.sys_processor_col._conn,
                       '/redfish/v1/Systems/437XR1138R2/Processors/CPU2',
-                      self.sys_processor_col.redfish_version, None)
+                      redfish_version=self.sys_processor_col.redfish_version,
+                      registries=None, root=self.sys_processor_col.root)
         ]
         mock_processor.assert_has_calls(calls)
         self.assertIsInstance(members, list)
@@ -164,10 +166,10 @@ class ProcessorCollectionTestCase(base.TestCase):
         # | WHEN |
         actual_summary = self.sys_processor_col.summary
         # | THEN |
-        self.assertEqual((16, sushy.PROCESSOR_ARCH_x86),
+        self.assertEqual((16, sushy.ProcessorArchitecture.X86),
                          actual_summary)
         self.assertEqual(16, actual_summary.count)
-        self.assertEqual(sushy.PROCESSOR_ARCH_x86,
+        self.assertEqual(sushy.ProcessorArchitecture.X86,
                          actual_summary.architecture)
 
         # reset mock
@@ -183,7 +185,7 @@ class ProcessorCollectionTestCase(base.TestCase):
         # | GIVEN |
         self._setUp_processor_summary()
         # | WHEN & THEN |
-        self.assertEqual((16, sushy.PROCESSOR_ARCH_x86),
+        self.assertEqual((16, sushy.ProcessorArchitecture.X86),
                          self.sys_processor_col.summary)
 
         self.conn.get.return_value.json.side_effect = None
@@ -197,5 +199,5 @@ class ProcessorCollectionTestCase(base.TestCase):
         # | GIVEN |
         self._setUp_processor_summary()
         # | WHEN & THEN |
-        self.assertEqual((16, sushy.PROCESSOR_ARCH_x86),
+        self.assertEqual((16, sushy.ProcessorArchitecture.X86),
                          self.sys_processor_col.summary)
